"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.toOpenApiPart = void 0;
const typebox_1 = require("@sinclair/typebox");
const string_prototype_matchall_1 = __importDefault(require("string.prototype.matchall"));
const lodash_1 = require("lodash");
const paramRegex = /{(?<name>[\w-_]+)(:(?<type>\w+))?(?<optional>\?)?}/g;
const mapToOpenApiType = (s) => {
    switch (s) {
        case "int":
            return "integer";
        case "bool":
            return "boolean";
        default:
            return "string";
    }
};
const stripTypes = (p) => p.replace(/:\w+}/g, "}");
const toOpenApiObject = (route) => {
    const model = route.body ? typebox_1.Type.Strict(route.body) : null;
    const responses = Object.keys(route.responses).map(k => ({ [k]: typebox_1.Type.Strict(route.responses[parseInt(k)]) }));
    const path = route.url.split("?")[0];
    const query = route.url.indexOf("?") > -1 ? route.url.split("?")[1] : null;
    const params = [...string_prototype_matchall_1.default(path, paramRegex)].map((p) => ({
        in: "path",
        name: p.groups["name"],
        required: true,
        schema: {
            type: mapToOpenApiType(p.groups["type"]),
        },
    }));
    const queryParams = query
        ? [...string_prototype_matchall_1.default(query, paramRegex)].map((p) => ({
            in: "path",
            name: p.groups["name"],
            required: !!p.groups["optional"],
            schema: {
                type: mapToOpenApiType(p.groups["type"]),
            },
        }))
        : null;
    const allParams = params.concat(queryParams || []);
    return {
        [stripTypes(path)]: {
            [route.method.toLowerCase()]: {
                parameters: allParams,
                responses: responses,
                ...(model
                    ? {
                        requestBody: {
                            required: true,
                            content: {
                                "application/json": {
                                    schema: model,
                                },
                            },
                        },
                    }
                    : {}),
            },
        },
    };
};
const toOpenApiPart = (routes) => routes.reduce((p, n) => lodash_1.merge(p, toOpenApiObject(n)), {});
exports.toOpenApiPart = toOpenApiPart;
