"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const open_api_1 = require("./open-api");
const js_yaml_1 = __importDefault(require("js-yaml"));
const typebox_1 = require("@sinclair/typebox");
describe("toOpenApiPart", () => {
    it("should return a valid open api", () => {
        const api = open_api_1.toOpenApiPart([
            {
                url: "/people/{name:string}/aged/{age:int}?{menOnly:bool?}",
                method: "post",
                responses: {
                    200: typebox_1.Type.String(),
                },
                body: typebox_1.Type.Object({
                    name: typebox_1.Type.String(),
                }, { additionalProperties: false }),
            },
        ]);
        expect(api).toBeTruthy();
        const ymlDef = js_yaml_1.default.dump(api);
        expect(ymlDef).toEqual(`/people/{name}/aged/{age}:
  post:
    parameters:
      - in: path
        name: name
        required: true
        schema:
          type: string
      - in: path
        name: age
        required: true
        schema:
          type: integer
    responses:
      - '200':
          type: string
    requestBody:
      required: true
      content:
        application/json:
          schema:
            additionalProperties: false
            type: object
            properties:
              name:
                type: string
            required:
              - name
`);
    });
});
