"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Router = void 0;
const typebox_1 = require("@sinclair/typebox");
const StatusCodes = [
    200, 201, 202, 203, 204, 205, 206, 207, 208, 226, 300, 301, 302, 303, 304,
    305, 306, 307, 308, 400, 401, 402, 403, 404, 405, 406, 407, 408, 409, 410,
    411, 412, 413, 414, 415, 416, 417, 418, 420, 422, 423, 424, 425, 426, 428,
    429, 431, 444, 449, 450, 451, 499, 500, 501, 502, 503, 504, 505, 506, 507,
    508, 509, 510, 511, 598, 599,
];
const DefaultResponses = {
    200: typebox_1.Type.Any({
        description: "OK",
    }),
};
const Router = (handlers = []) => {
    const buildHandler = (method) => (path, bodyOrResponses, responses) => (handler) => {
        const isSafe = ["get", "options", "head"].includes(method);
        const body = isSafe ? undefined : bodyOrResponses;
        const _responses = isSafe ? bodyOrResponses : responses;
        return exports.Router([
            {
                method,
                url: path,
                handler,
                body,
                responses: _responses || DefaultResponses,
            },
            ...handlers,
        ]);
    };
    return {
        handlers,
        get: buildHandler("get"),
        head: buildHandler("head"),
        options: buildHandler("options"),
        post: buildHandler("post"),
        put: buildHandler("put"),
        delete: buildHandler("delete"),
    };
};
exports.Router = Router;
